searchData={"items":[{"type":"module","title":"DualMap","doc":"A DualMap is simply a dual-entry map struct that allows you to reference pairs of data using both, a key or a value. In a DualMap you can look up a value from its key or a key from its value.\n\nIn simple terms we could say that a DualMap is a map where there is no difference between key and value, both can be either one or the other.","ref":"DualMap.html"},{"type":"module","title":"How does it work? - DualMap","doc":"A DualMap actually stores 2 maps, a direct one with the key => value pairs, and a reverse one with the value => key pairs. At the same time it also stores metadata about the names (ids) of the datas (called master keys).\n\nTo create a new DualMap you must use the `DualMap.new` function. You must pass to it a pair of names that will be the identifiers of the master keys.\n\n```elixir\nDualMap.new({:hostname, :ip})\n```\n\nThe order of the master keys is important. If you later want to make insertions into the DualMap and you use the `DualMap.put_ordered` function the value pairs will assume that they are ordered as defined at the time of creating the DualMap with `DualMap.new`.","ref":"DualMap.html#module-how-does-it-work"},{"type":"module","title":"Let's see some examples: - DualMap","doc":"```elixir\niex> dm = DualMap.new({:hostname, :ip})\n[]\niex> DualMap.put_ordered(dm, [\n  {\"ns3\", \"192.168.0.4\"},\n  {\"ns2\", \"192.168.0.3\"},\n  {\"ns1\", \"192.168.0.2\"}\n])\n[\n  {\"ns1\", \"192.168.0.2\"},\n  {\"ns2\", \"192.168.0.3\"},\n  {\"ns3\", \"192.168.0.4\"}\n]\niex> DualMap.delete(dm, :ip, \"192.168.0.3\")\n[\n  {\"ns1\", \"192.168.0.2\"},\n  {\"ns3\", \"192.168.0.4\"}\n]\n```","ref":"DualMap.html#module-let-s-see-some-examples"},{"type":"function","title":"DualMap.count/1","doc":"Return de size of the DualMap counting the number of pairs.","ref":"DualMap.html#count/1"},{"type":"function","title":"DualMap.delete/3","doc":"Delete a pair of datas and returns the DualMap without that pair. The pair is found looking for `key` in the the internal map indexed by `master_key`.","ref":"DualMap.html#delete/3"},{"type":"function","title":"Examples - DualMap.delete/3","doc":"iex> dm = DualMap.new({:hostname, :ip}, [\n      {\"ns3\", \"192.168.0.4\"},\n      {\"ns2\", \"192.168.0.3\"},\n      {\"ns1\", \"192.168.0.2\"}\n    ])\n    [\n      {\"ns1\", \"192.168.0.2\"},\n      {\"ns2\", \"192.168.0.3\"},\n      {\"ns3\", \"192.168.0.4\"}\n    ]\n    iex> DualMap.delete(dm, :ip, \"192.168.0.3\")\n    [\n      {\"ns1\", \"192.168.0.2\"},\n      {\"ns3\", \"192.168.0.4\"}\n    ]","ref":"DualMap.html#delete/3-examples"},{"type":"function","title":"DualMap.drop/3","doc":"Just the same as `delete/3` but you can pass a list of keys to delete.","ref":"DualMap.html#drop/3"},{"type":"function","title":"Examples - DualMap.drop/3","doc":"iex> dm = DualMap.new({:hostname, :ip}, [\n      {\"ns3\", \"192.168.0.4\"},\n      {\"ns2\", \"192.168.0.3\"},\n      {\"ns1\", \"192.168.0.2\"}\n    ])\n    [\n      {\"ns1\", \"192.168.0.2\"},\n      {\"ns2\", \"192.168.0.3\"},\n      {\"ns3\", \"192.168.0.4\"}\n    ]\n    iex> DualMap.drop(dm, :ip, [\"192.168.0.3\", \"192.168.0.2\"])\n    [{\"ns3\", \"192.168.0.4\"}]","ref":"DualMap.html#drop/3-examples"},{"type":"function","title":"DualMap.equal?/2","doc":"Checks if two DualMaps are equal.\n\nTwo maps are considered to be equal if both internal maps contains the same keys and values.","ref":"DualMap.html#equal?/2"},{"type":"function","title":"DualMap.fetch/3","doc":"Just as `get/4` but do not accept default parameter. If the key exists, will return the tuple `{:ok, value}` and if not `:error`.","ref":"DualMap.html#fetch/3"},{"type":"function","title":"Examples - DualMap.fetch/3","doc":"iex> dm = DualMap.new({:hostname, :ip}, [\n      {\"ns3\", \"192.168.0.4\"},\n      {\"ns2\", \"192.168.0.3\"},\n      {\"ns1\", \"192.168.0.2\"}\n    ])\n    iex> DualMap.fetch(dm, :ip, \"192.168.0.4\")\n    {:ok, \"ns3\"}\n    iex> DualMap.fetch(dm, :ip, \"192.168.0.6\")\n    :error","ref":"DualMap.html#fetch/3-examples"},{"type":"function","title":"DualMap.fetch!/3","doc":"Work equals to `fetch/3` but erroring out if key doesn't exists.","ref":"DualMap.html#fetch!/3"},{"type":"function","title":"DualMap.get/4","doc":"Returns the value asociated to `key` taking the internal map indexed by `master_key`. If `key` does not exists in the map, `default` or `nil` is returned.","ref":"DualMap.html#get/4"},{"type":"function","title":"Examples - DualMap.get/4","doc":"iex> dm = DualMap.new({:hostname, :ip}, [\n      {\"ns3\", \"192.168.0.4\"},\n      {\"ns2\", \"192.168.0.3\"},\n      {\"ns1\", \"192.168.0.2\"}\n    ])\n    [\n      {\"ns1\", \"192.168.0.2\"},\n      {\"ns2\", \"192.168.0.3\"},\n      {\"ns3\", \"192.168.0.4\"}\n    ]\n    iex> DualMap.get(dm, :ip, \"192.168.0.4\")\n    \"ns3\"","ref":"DualMap.html#get/4-examples"},{"type":"function","title":"DualMap.get_map/2","doc":"Return the complete internal map indexed by `master_key`.","ref":"DualMap.html#get_map/2"},{"type":"function","title":"Examples - DualMap.get_map/2","doc":"iex> dm = DualMap.new({:hostname, :ip}, [\n      {\"ns3\", \"192.168.0.4\"},\n      {\"ns2\", \"192.168.0.3\"},\n      {\"ns1\", \"192.168.0.2\"}\n    ])\n    [\n      {\"ns1\", \"192.168.0.2\"},\n      {\"ns2\", \"192.168.0.3\"},\n      {\"ns3\", \"192.168.0.4\"}\n    ]\n    iex> DualMap.get_map(dm, :hostname)\n    %{\n      \"ns1\" => \"192.168.0.2\",\n      \"ns2\" => \"192.168.0.3\",\n      \"ns3\" => \"192.168.0.4\"\n    }","ref":"DualMap.html#get_map/2-examples"},{"type":"function","title":"DualMap.has?/2","doc":"Checks if `key` exists within DualMap.","ref":"DualMap.html#has?/2"},{"type":"function","title":"Examples - DualMap.has?/2","doc":"iex> dm = DualMap.new({:hostname, :ip}, [\n      {\"ns3\", \"192.168.0.4\"},\n      {\"ns2\", \"192.168.0.3\"},\n      {\"ns1\", \"192.168.0.2\"}\n    ])\n    [\n      {\"ns1\", \"192.168.0.2\"},\n      {\"ns2\", \"192.168.0.3\"},\n      {\"ns3\", \"192.168.0.4\"}\n    ]\n    iex> DualMap.has?(dm, \"192.168.0.4\")\n    true\n    iex> DualMap.has?(dm, \"ns2\")\n    true\n    iex> DualMap.has?(dm, \"ns5\")\n    false","ref":"DualMap.html#has?/2-examples"},{"type":"function","title":"DualMap.keys/2","doc":"Return a list with all the keys of the internal map indexed by `master_key`.","ref":"DualMap.html#keys/2"},{"type":"function","title":"Examples - DualMap.keys/2","doc":"iex> dm = DualMap.new({:hostname, :ip}, [\n      {\"ns3\", \"192.168.0.4\"},\n      {\"ns2\", \"192.168.0.3\"},\n      {\"ns1\", \"192.168.0.2\"}\n    ])\n    iex> DualMap.keys(dm, :hostname)\n    [\"ns1\", \"ns2\", \"ns3\"]","ref":"DualMap.html#keys/2-examples"},{"type":"function","title":"DualMap.member?/2","doc":"Checks if the pair `key_value` (tuple size 2) exists within DualMap either as key => value or as value => key.","ref":"DualMap.html#member?/2"},{"type":"function","title":"Examples - DualMap.member?/2","doc":"iex> dm = DualMap.new({:hostname, :ip}, [\n      {\"ns3\", \"192.168.0.4\"},\n      {\"ns2\", \"192.168.0.3\"},\n      {\"ns1\", \"192.168.0.2\"}\n    ])\n    [\n      {\"ns1\", \"192.168.0.2\"},\n      {\"ns2\", \"192.168.0.3\"},\n      {\"ns3\", \"192.168.0.4\"}\n    ]\n    iex> DualMap.member?(dm, {\"192.168.0.4\", \"ns3\"})\n    true\n    iex> DualMap.member?(dm, {\"ns3\", \"192.168.0.4\"})\n    true\n    iex> DualMap.member?(dm, {\"ns1\", \"192.168.0.4\"})\n    false","ref":"DualMap.html#member?/2-examples"},{"type":"function","title":"DualMap.new/1","doc":"Returns an empty DualMap struct. The order of the master keys are important for posterior operations with the struct.","ref":"DualMap.html#new/1"},{"type":"function","title":"Examples - DualMap.new/1","doc":"iex> DualMap.new({:hostname, :ip})\n    []","ref":"DualMap.html#new/1-examples"},{"type":"function","title":"DualMap.new/2","doc":"Returns a DualMap struct initialized with the values indicated in the second argument. As the `new/1` function, the order of the master keys are important for posterior operations with the struct.","ref":"DualMap.html#new/2"},{"type":"function","title":"Examples - DualMap.new/2","doc":"# Initializing with one pair of values\n    iex> DualMap.new({:hostname, :ip}, {\"ns1\", \"192.168.0.2\"})\n    [{\"ns1\", \"192.168.0.2\"}]\n\n    # Initializing with more than one pair of values\n    iex> DualMap.new({:hostname, :ip}, [\n      {\"ns3\", \"192.168.0.4\"},\n      {\"ns2\", \"192.168.0.3\"},\n      {\"ns1\", \"192.168.0.2\"}\n    ])\n    [\n      {\"ns1\", \"192.168.0.2\"},\n      {\"ns2\", \"192.168.0.3\"},\n      {\"ns3\", \"192.168.0.4\"}\n    ]","ref":"DualMap.html#new/2-examples"},{"type":"function","title":"DualMap.put/3","doc":"Insert or replace one or more pairs of datas in a DualMap. If the third parameters is a list of tuples, every one is inserted/replaced in the DualMap secuentialy. With this function you need pass the a master_key to indicate which value of the tuple will be interpreted as key and which one as value.","ref":"DualMap.html#put/3"},{"type":"function","title":"Examples - DualMap.put/3","doc":"iex> dm = DualMap.new({:hostname, :ip})\n    []\n    # Inserting/replacing many\n    iex> DualMap.put(dm, :ip, [\n      {\"192.168.0.4\", \"ns3\"},\n      {\"192.168.0.3\", \"ns2\"},\n      {\"192.168.0.2\", \"ns1\"}\n    ])\n    [\n      {\"ns1\", \"192.168.0.2\"},\n      {\"ns2\", \"192.168.0.3\"},\n      {\"ns3\", \"192.168.0.4\"}\n    ]\n    Or inserting just one\n    iex> DualMap.put(dm, :ip, {\"192.168.0.4\", \"ns3\"})\n    [{\"ns3\", \"192.168.0.4\"}]","ref":"DualMap.html#put/3-examples"},{"type":"function","title":"DualMap.put_ordered/2","doc":"This function is similar to `put/3` but you does not need pass a master key because the function will assume that you are sending the keys and values in the same order as you defined when you created the DualMap with `new/1` or `new/2`.","ref":"DualMap.html#put_ordered/2"},{"type":"function","title":"Examples - DualMap.put_ordered/2","doc":"iex> dm = DualMap.new({:hostname, :ip})\n    []\n    iex> DualMap.put_ordered(dm, [\n      {\"ns3\", \"192.168.0.4\"},\n      {\"ns2\", \"192.168.0.3\"},\n      {\"ns1\", \"192.168.0.2\"}\n    ])\n    [\n      {\"ns1\", \"192.168.0.2\"},\n      {\"ns2\", \"192.168.0.3\"},\n      {\"ns3\", \"192.168.0.4\"}\n    ]","ref":"DualMap.html#put_ordered/2-examples"},{"type":"function","title":"DualMap.put_ordered/3","doc":"","ref":"DualMap.html#put_ordered/3"},{"type":"type","title":"DualMap.t/0","doc":"DualMap struct","ref":"DualMap.html#t:t/0"},{"type":"function","title":"DualMap.to_list/2","doc":"Return a list of the pairs `{key, value}` taking the map indexed by the first master_key defined with `new/1` or `new/2`. This function is used by `inspect` to print the DualMap.\n\nIf you also pass an option `:pairs_inverted`, the list will have the pairs with key/value inverted because will take the internal map indexed by the second master_key defined with `new/1` or `new/2`.","ref":"DualMap.html#to_list/2"},{"type":"function","title":"DualMap.values/2","doc":"Return a list with all the values of the internal map indexed by `master_key`.","ref":"DualMap.html#values/2"},{"type":"function","title":"Examples - DualMap.values/2","doc":"iex> dm = DualMap.new({:hostname, :ip}, [\n      {\"ns3\", \"192.168.0.4\"},\n      {\"ns2\", \"192.168.0.3\"},\n      {\"ns1\", \"192.168.0.2\"}\n    ])\n    [\n      {\"ns1\", \"192.168.0.2\"},\n      {\"ns2\", \"192.168.0.3\"},\n      {\"ns3\", \"192.168.0.4\"}\n    ]\n    iex> DualMap.values(dm, :hostname)\n    [\"192.168.0.2\", \"192.168.0.3\", \"192.168.0.4\"]","ref":"DualMap.html#values/2-examples"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.1"}}